#!/bin/bash

## =====================================================================
##  check_ngx_lua
##  runs some sanity checks against an nginx binary to confirm that the
##  ngx_lua module is built in and is built with luajit support
##
##  usage:
##    check_ngx_lua.sh <path_to_nginx_binary>
## =====================================================================

NGINX_BIN=$1
if [ -z $NGINX_BIN ] || [ ! -f $NGINX_BIN ]; then
  echo "Usage: $0 <path_to_nginx_binary>"
  exit 1
fi

echo "Checking nginx binary $NGINX_BIN"

# if objdump exists use that instead
OBJDUMP=$(which objdump)
if [ ! -z $OBJDUMP ]; then
  DUMPER="${OBJDUMP} -T"
else
  DUMPER="strings"
fi

# check the access_by_lua symbol is in the binary
$DUMPER $NGINX_BIN | grep -q 'ngx_http_lua_access_by_lua'
if [ $? -ne 1 ]; then
  echo " * OK: ngx_lua is built in"
else
  echo " * ERROR: the ngx_lua module isn't built into nginx"
  exit 1
fi

# check if we're dynamically linked against libluajit
LDD=$(which ldd)
$LDD $NGINX_BIN | grep -q 'luajit'
if [ $? -eq 0 ]; then 
  echo " * OK: nginx is dynamically linked against luajit"
else
  # if not dynamically linked lets see if we're statically linked
  $DUMPER $NGINX_BIN | grep -q 'luaJIT_version'
  if [ $? -ne 1 ]; then
    echo " * OK: nginx is statically linked against luajit"
  else
    echo " * ERROR: your ngx_lua module isn't linked against the LuaJIT library"
    exit 1
  fi
fi

echo "Congratulations, your Nginx is ready for Signal Sciences!"
